﻿using System.Windows;
using ThinkGeo.Core;
using ThinkGeo.UI.Wpf;

namespace Quickstart
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void MapViewLoaded(object sender, RoutedEventArgs e)
        {
            // Set the Map Unit.
            mapView.MapUnit = GeographyUnit.Meter;

            // Add a background layer
            var backgroundOverlay = new LayerOverlay();
            backgroundOverlay.Layers.Add(new BackgroundLayer(new GeoSolidBrush(GeoColor.FromHtml("#F0EEE8"))));

            // This ThinkGeo Cloud test key is exclusively for demonstration purposes and is limited to requesting base map 
            // tiles only. Do not use it in your own applications, as it may be restricted or disabled without prior notice. 
            // Please visit https://cloud.thinkgeo.com to create a free key for your own use.
            var cloudRasterBaseMapOverlay = new ThinkGeoCloudRasterMapsOverlay("USlbIyO5uIMja2y0qoM21RRM6NBXUad4hjK3NBD6pD0~", "f6OJsvCDDzmccnevX55nL7nXpPDXXKANe5cN6czVjCH0s8jhpCH-2A~~", ThinkGeoCloudRasterMapsMapType.Light);
            mapView.Overlays.Add(cloudRasterBaseMapOverlay);

            // Add a shapefile layer with point style.
            var customDataOverlay = new LayerOverlay();
            var capitalLayer = new ShapeFileFeatureLayer(@"AppData/WorldCapitals.shp");
            capitalLayer.FeatureSource.ProjectionConverter = new ProjectionConverter(4326, 3857);

            var capitalStyle = new PointStyle()
            {
                SymbolType = PointSymbolType.Circle,
                SymbolSize = 8,
                FillBrush = new GeoSolidBrush(GeoColors.White),
                OutlinePen = new GeoPen(GeoColors.Black, 2)
            };
            capitalLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = capitalStyle;
            capitalLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            customDataOverlay.Layers.Add(capitalLayer);
            mapView.Overlays.Add(customDataOverlay);

            capitalLayer.Open();
            // Set the extent of capitalLayer for the Map. 
            mapView.CurrentExtent = capitalLayer.GetBoundingBox();
        }
    }
}
